@@ -1,7 +1,7 @@
 # This function takes data as input and produced a network. It is used inside bootnet:
 estimateNetwork <- function(
   data,
-  default = c("none", "EBICglasso", "pcor","IsingFit","IsingSampler", "huge","adalasso","mgm"),
+  default = c("none", "EBICglasso", "pcor","IsingFit","IsingSampler", "huge","adalasso","mgm","relimp"),
   fun, # A function that takes data and returns a network or list entitled "graph" and "thresholds". optional.
   prepFun, # Fun to produce the correlation or covariance matrix
   prepArgs, # list with arguments for the correlation function
@@ -17,12 +17,14 @@ estimateNetwork <- function(
   .dots = list(),
   weighted = TRUE,
   signed = TRUE,
+  directed,
   # plot = TRUE, # Plot the network?
   ..., # Arguments to the 'fun' function
-  .input # Skips most of first steps if supplied
+  .input, # Skips most of first steps if supplied
+  memorysaver = FALSE # If set to FALSE data, estimator and results are not stored.
 ){
-#   if (default[[1]]=="glasso") default <- "EBICglasso"
-#   default <- match.arg(default)
+  if (default[[1]]=="glasso") default <- "EBICglasso"
+  default <- match.arg(default)
 #   
   # If NAs and default can't handle, stop:
   # if (any(is.na(data)) && default %in% c("huge","adalasso")){
@@ -38,8 +40,14 @@ estimateNetwork <- function(
   if (is.matrix(data)){
     data <- as.data.frame(data)
   }
-  
-  
+ 
+  if (missing(directed)){
+    if (!default %in% c("graphicalVAR","relimp","DAG")){
+      directed <- FALSE 
+    } else {
+      directed <- TRUE
+    }
+  }
   
   N <- ncol(data)
   Np <- nrow(data)
@@ -119,10 +127,20 @@ estimateNetwork <- function(
     default = default,
     weighted = weighted,
     signed = signed,
+    directed=directed,
     .input = .input
   )
   class(sampleResult) <- c("bootnetResult", "list")
   
+  # Memory save:
+  if(memorysaver)
+  {
+    sampleResult$results <- NA
+    sampleResult$estimator <- NA
+    sampleResult$data <- NA
+    sampleResult$.input <- NA
+  }
+  
   # Plot?
 #   if (plot){
 #     plot(sampleResult,labels=labels,layout = "spring", ...)
